package main

import (
	"flag"
	"fmt"
	"github.com/gin-gonic/gin"
	"log"
)

func main() {
	// Define a string flag with a name "c", default value "./conf/config.yaml", and a usage description.
	configPath := flag.String("c", "./conf/config.yaml", "Path to the configuration file")

	// Parse the command line flags
	flag.Parse()

	// Output the path of the configuration file
	fmt.Println("Configuration file path:", *configPath)

	// Attempt to parse the configuration file at configPath
	config, err := LoadConfig(*configPath)
	if err != nil {
		log.Fatal("Error parsing configuration file:", err)
		return
	}

	mainLogger := setupLogs()
	mainLogger.Infof("[配置]:%+v", config)

	db, errInitDB := InitializeGorm(config.MySQL)
	if errInitDB != nil {
		mainLogger.Fatal("Error initializing database:", errInitDB)
		return
	}

	// Create a Gin router instance
	router := gin.Default()

	// Define a simple GET route
	router.GET("/", func(c *gin.Context) {
		c.JSON(200, gin.H{
			"message": "Hello, World!",
		})
	})

	// Start the server on default port 8080
	router.Run()
}
